==> kinesis-0.8.2-sources.jar: software/amazon/awscdk/services/kinesis/StreamName.java <==
package software.amazon.awscdk.services.kinesis;
/**
 * The name of the stream.
 */
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.kinesis.$Module.class, fqn = "@aws-cdk/aws-kinesis.StreamName")
public class StreamName extends software.amazon.awscdk.Token {
    protected StreamName(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    /**
     * Creates a token that resolves to `value`.
     * 
     * If value is a function, the function is evaluated upon resolution and
     * the value it returns will be used as the token's value.
     * 
     * displayName is used to represent the Token when it's embedded into a string; it
     * will look something like this:
     * 
     *       "embedded in a larger string is ${Token[DISPLAY_NAME.123]}"
     * 
     * This value is used as a hint to humans what the meaning of the Token is,
     * and does not have any effect on the evaluation.
     * 
     * Must contain only alphanumeric and simple separator characters (_.:-).
     * @param valueOrFunction What this token will evaluate to, literal or function.
     * @param displayName A human-readable display hint for this Token
     */
    public StreamName(@javax.annotation.Nullable final java.lang.Object valueOrFunction, @javax.annotation.Nullable final java.lang.String displayName) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.of(valueOrFunction), java.util.stream.Stream.of(displayName)).toArray());
    }
    /**
     * Creates a token that resolves to `value`.
     * 
     * If value is a function, the function is evaluated upon resolution and
     * the value it returns will be used as the token's value.
     * 
     * displayName is used to represent the Token when it's embedded into a string; it
     * will look something like this:
     * 
     *       "embedded in a larger string is ${Token[DISPLAY_NAME.123]}"
     * 
     * This value is used as a hint to humans what the meaning of the Token is,
     * and does not have any effect on the evaluation.
     * 
     * Must contain only alphanumeric and simple separator characters (_.:-).
     * @param valueOrFunction What this token will evaluate to, literal or function.
     */
    public StreamName(@javax.annotation.Nullable final java.lang.Object valueOrFunction) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.of(valueOrFunction).toArray());
    }
    /**
     * Creates a token that resolves to `value`.
     * 
     * If value is a function, the function is evaluated upon resolution and
     * the value it returns will be used as the token's value.
     * 
     * displayName is used to represent the Token when it's embedded into a string; it
     * will look something like this:
     * 
     *       "embedded in a larger string is ${Token[DISPLAY_NAME.123]}"
     * 
     * This value is used as a hint to humans what the meaning of the Token is,
     * and does not have any effect on the evaluation.
     * 
     * Must contain only alphanumeric and simple separator characters (_.:-).
     */
    public StreamName() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }
}

==> kinesis-0.9.0-sources.jar: software/amazon/awscdk/services/kinesis/StreamName.java <==
package software.amazon.awscdk.services.kinesis;

/**
 * The name of the stream.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.4 (build e80a889)", date = "2018-09-11T09:57:27.984Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.kinesis.$Module.class, fqn = "@aws-cdk/aws-kinesis.StreamName")
public class StreamName extends software.amazon.awscdk.Token {
    protected StreamName(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    /**
     * Creates a token that resolves to `value`.
     * 
     * If value is a function, the function is evaluated upon resolution and
     * the value it returns will be used as the token's value.
     * 
     * displayName is used to represent the Token when it's embedded into a string; it
     * will look something like this:
     * 
     *       "embedded in a larger string is ${Token[DISPLAY_NAME.123]}"
     * 
     * This value is used as a hint to humans what the meaning of the Token is,
     * and does not have any effect on the evaluation.
     * 
     * Must contain only alphanumeric and simple separator characters (_.:-).
     * @param valueOrFunction What this token will evaluate to, literal or function.
     * @param displayName A human-readable display hint for this Token
     */
    public StreamName(final java.lang.Object valueOrFunction, @javax.annotation.Nullable final java.lang.String displayName) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(valueOrFunction, "valueOrFunction is required")), java.util.stream.Stream.of(displayName)).toArray());
    }
    /**
     * Creates a token that resolves to `value`.
     * 
     * If value is a function, the function is evaluated upon resolution and
     * the value it returns will be used as the token's value.
     * 
     * displayName is used to represent the Token when it's embedded into a string; it
     * will look something like this:
     * 
     *       "embedded in a larger string is ${Token[DISPLAY_NAME.123]}"
     * 
     * This value is used as a hint to humans what the meaning of the Token is,
     * and does not have any effect on the evaluation.
     * 
     * Must contain only alphanumeric and simple separator characters (_.:-).
     * @param valueOrFunction What this token will evaluate to, literal or function.
     */
    public StreamName(final java.lang.Object valueOrFunction) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.of(java.util.Objects.requireNonNull(valueOrFunction, "valueOrFunction is required")).toArray());
    }
}
